==> biomedsheets-0.5.1.tar.gz: biomedsheets-0.5.1/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
import pip
from pip.req import parse_requirements

import versioneer

__author__ = 'Manuel Holtgrewe <manuel.holtgrewe@bihealth.de>'

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

reqs = parse_requirements('requirements.txt', session=pip.download.PipSession())

requirements = [str(ir.req) for ir in reqs]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='biomedsheets',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description=(
        'Python 3 library for accessing and managing BioMedical sheets'),
    long_description=readme + '\n\n' + history,
    author='Manuel Holtgrewe',
    author_email='manuel.holtgrewe@bihealth.de',
    url='https://github.com/bihealth/biomedsheets',
    packages=find_packages(),
    package_dir={
        'biomedsheets': 'biomedsheets',
    },
    entry_points={
        'console_scripts': [
            'biomedsheets = biomedsheets.__main__:main',
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license='MIT license',
    zip_safe=False,
    keywords='biomedsheets',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)

==> biomedsheets-0.5.5.tar.gz: biomedsheets-0.5.5/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
from setuptools import setup, find_packages

import versioneer

__author__ = 'Manuel Holtgrewe <manuel.holtgrewe@bihealth.de>'


def parse_requirements(path):
    """Parse ``requirements.txt`` at ``path``."""
    requirements = []
    with open(path, 'rt') as reqs_f:
        for line in reqs_f:
            line = line.strip()
            if line.startswith('-r'):
                fname = line.split()[1]
                inner_path = os.path.join(
                    os.path.dirname(path), fname)
                requirements += parse_requirements(inner_path)
            elif line != '' and not line.startswith('#'):
                requirements.append(line)
    return requirements


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = parse_requirements('requirements.txt')

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='biomedsheets',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description=(
        'Python 3 library for accessing and managing BioMedical sheets'),
    long_description=readme + '\n\n' + history,
    author='Manuel Holtgrewe',
    author_email='manuel.holtgrewe@bihealth.de',
    url='https://github.com/bihealth/biomedsheets',
    packages=find_packages(),
    package_dir={
        'biomedsheets': 'biomedsheets',
    },
    entry_points={
        'console_scripts': [
            'biomedsheets = biomedsheets.__main__:main',
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license='MIT license',
    zip_safe=False,
    keywords='biomedsheets',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
